<?php
/**
 * believe functions and definitions
 *
 * @package Believe
 * @since Believe 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since believe 1.0
 */
if ( ! isset( $content_width ) )
	$content_width = 620; /* pixels */

if ( ! function_exists( 'believe_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @package Believe
 * @since Believe 1.0
 */
function believe_setup() {

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );

	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/tweaks.php' );



	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on believe, use a find and replace
	 * to change 'believe' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'believe', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	add_editor_style();
	
	// Enable post thumbnails
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 50, 50, true );
	add_image_size( 'single-post-thumbnail', 610, 220, true );


    
	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'believe' ),
	) );

	/**
	 * Add support for the Aside and Gallery Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', ) );
}
endif; // believe_setup
add_action( 'after_setup_theme', 'believe_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since believe 1.0
 */
function believe_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'believe' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );
}
add_action( 'widgets_init', 'believe_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function believe_scripts() {
	global $post;

	wp_enqueue_style( 'style', get_stylesheet_uri() );

	wp_enqueue_script( 'jquery' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'believe_scripts' );

/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );
