<?php
/**
 * Sample implementation of the Custom Header feature
 * http://codex.wordpress.org/Custom_Headers
 *
 * You can add an optional custom header image to header.php like so ...
 *
 * @package Believe
 * @since Believe 1.0
 */

function believe_custom_header_setup() {
	// The default header text color
	define('HEADER_TEXTCOLOR', '');

	// By leaving empty, we allow for random image rotation.
	define('HEADER_IMAGE', '%s/img/header.jpg'); // %s is the template dir uri

	// The height and width of your custom header.
	// Add a filter to believe_header_image_width and believe_header_image_height to change these values.
	define( 'HEADER_IMAGE_WIDTH', apply_filters( 'believe_header_image_width', 620 ) );
	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'believe_header_image_height', 250 ) );
	define('NO_HEADER_TEXT', true );

	// Turn on random header image rotation by default.
	add_theme_support( 'custom-header', array( 'random-default' => false ) );

	// Add a way for the custom header to be styled in the admin panel that controls custom headers
	add_custom_image_header( 'believe_header_style', 'believe_admin_header_style', 'believe_admin_header_image' );
}
add_action( 'after_setup_theme', 'believe_custom_header_setup' );

if ( ! function_exists( 'believe_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @since believe 1.0
 */
function believe_header_style() {

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == get_header_textcolor() )
		return;
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == get_header_textcolor() ) :
	?>
		.site-title,
		.site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo get_header_textcolor(); ?> !important;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // believe_header_style

if ( ! function_exists( 'believe_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_custom_image_header() in believe_setup().
 *
 * @since believe 1.0
 */
function believe_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
	}
	#headimg h1 {
	}
	#headimg h1 a {
	}
	#desc {
	}
	#headimg img {
	}
	</style>
<?php
}
endif; // believe_admin_header_style

if ( ! function_exists( 'believe_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_custom_image_header() in believe_setup().
 *
 * @since believe 1.0
 */
function believe_admin_header_image() { ?>
	<div id="headimg">
		<?php
		if ( 'blank' == get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) || '' == get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:#' . get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) . ';"';
		?>
		<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // believe_admin_header_image